<?php

namespace Bixo\MarketingProject\Providers;

use Illuminate\Support\ServiceProvider;

class MarketingProjectServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'marketing_project');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'marketing_project');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerMarketingProject();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerMarketingProject()
    {
        $this->app->bind('marketing_project', function($app) {
            return new MarketingProject($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('MarketingProject', 'Lavalite\MarketingProject\Facades\MarketingProject');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.marketing_project', function ($app) {
            return $this->app->make('Bixo\MarketingProject\MarketingProject');
        });

                // Bind Project to repository
        $this->app->bind(
            'Bixo\MarketingProject\Interfaces\ProjectRepositoryInterface',
            \Bixo\MarketingProject\Repositories\Eloquent\ProjectRepository::class
        );

        $this->app->register(\Bixo\MarketingProject\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\MarketingProject\Providers\RouteServiceProvider::class);
                // $this->app->register(\Bixo\MarketingProject\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and marketing_project's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.marketing_project'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeMarketingProject::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.marketing_project'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/marketing_project.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/marketing_project')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/marketing_project')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
